@@ -104,7 +104,10 @@ def date_within_last(date, number, period):
 
 
 def str_to_datetime(date_time, str_format="%Y-%m-%d %H:%M:%S"):
-    return datetime.strptime(date_time, str_format)
+    try:
+        return datetime.strptime(date_time, str_format)
+    except ValueError:
+        return datetime.strptime(date_time, '%Y-%m-%d')
 
 
 def get_datetime(date_string):
@@ -569,11 +572,13 @@ def invoke_set_value_task(conf, task_id, vtiger_access):
 
                                 # retry to execute query
 
+
                                 url = '{vtiger_url}/webservice.php?operation=query&sessionName={sessionName}&query={query}'.format(
                                     sessionName=session_name, query=query, vtiger_url=vtiger_access.get('vtiger_url'))
                                 url = url.replace("''", "' '")
                                 response, status = invoke_http_request(url, request_type, headers)
 
+
                                 vtiger_access['vtiger_session'] = session_name
                                 Variable.update(key='vtiger_access', value=vtiger_access, serialize_json=True)
 
